==> haskell-language-python-0.5.8-242-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-language-python.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 language-python
version:              0.5.8
visibility:           public
id:                   language-python-0.5.8-DOaH4oMg5MLEuQGiYcbeJN
key:                  language-python-0.5.8-DOaH4oMg5MLEuQGiYcbeJN
license:              BSD-3-Clause
copyright:            (c) 2008-2019 Bernard James Pope
maintainer:           florbitous@gmail.com
author:               Bernard James Pope (Bernie Pope)
stability:            experimental
homepage:             http://github.com/bjpop/language-python 
synopsis:             Parsing and pretty printing of Python code. 
description:
    language-python is a Haskell library for lexical analysis, parsing
    and pretty printing Python code. It supports versions 2.x and 3.x of Python.

category:             Language
abi:                  3c010c605696bb581fbcd2972ab64e10
exposed:              True
exposed-modules:
    Language.Python.Common Language.Python.Common.AST
    Language.Python.Common.ParseError
    Language.Python.Common.ParserMonad Language.Python.Common.Pretty
    Language.Python.Common.PrettyAST
    Language.Python.Common.PrettyParseError
    Language.Python.Common.PrettyToken
    Language.Python.Common.SrcLocation
    Language.Python.Common.StringEscape Language.Python.Common.Token
    Language.Python.Version2 Language.Python.Version2.Lexer
    Language.Python.Version2.Parser Language.Python.Version3
    Language.Python.Version3.Lexer Language.Python.Version3.Parser

hidden-modules:
    Language.Python.Common.ParserUtils
    Language.Python.Common.LexerUtils
    Language.Python.Version3.Parser.Parser
    Language.Python.Version3.Parser.Lexer
    Language.Python.Version2.Parser.Parser
    Language.Python.Version2.Parser.Lexer

import-dirs:          /usr/lib/ghc-9.4.8/site-local/language-python-0.5.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/language-python-0.5.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/language-python-0.5.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-python
hs-libraries:         HSlanguage-python-0.5.8-DOaH4oMg5MLEuQGiYcbeJN
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    monads-tf-0.3.0.1-EWNCSzWUnVI56Lvw8xK8It pretty-1.1.3.6
    transformers-0.5.6.2 utf8-string-1.0.2-9Em8uVxkJRhLhA62Ke5gub

haddock-interfaces:
    /usr/share/doc/haskell-language-python/html/language-python.haddock

haddock-html:         /usr/share/doc/haskell-language-python/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-language-python-0.5.8-245-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-language-python.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 language-python
version:              0.5.8
visibility:           public
id:                   language-python-0.5.8-FU2I1gQplKQCxtgX2Peano
key:                  language-python-0.5.8-FU2I1gQplKQCxtgX2Peano
license:              BSD-3-Clause
copyright:            (c) 2008-2019 Bernard James Pope
maintainer:           florbitous@gmail.com
author:               Bernard James Pope (Bernie Pope)
stability:            experimental
homepage:             http://github.com/bjpop/language-python 
synopsis:             Parsing and pretty printing of Python code. 
description:
    language-python is a Haskell library for lexical analysis, parsing
    and pretty printing Python code. It supports versions 2.x and 3.x of Python.

category:             Language
abi:                  7f02ee81a5b06da5378e96cfbadcdffd
exposed:              True
exposed-modules:
    Language.Python.Common Language.Python.Common.AST
    Language.Python.Common.ParseError
    Language.Python.Common.ParserMonad Language.Python.Common.Pretty
    Language.Python.Common.PrettyAST
    Language.Python.Common.PrettyParseError
    Language.Python.Common.PrettyToken
    Language.Python.Common.SrcLocation
    Language.Python.Common.StringEscape Language.Python.Common.Token
    Language.Python.Version2 Language.Python.Version2.Lexer
    Language.Python.Version2.Parser Language.Python.Version3
    Language.Python.Version3.Lexer Language.Python.Version3.Parser

hidden-modules:
    Language.Python.Common.ParserUtils
    Language.Python.Common.LexerUtils
    Language.Python.Version3.Parser.Parser
    Language.Python.Version3.Parser.Lexer
    Language.Python.Version2.Parser.Parser
    Language.Python.Version2.Parser.Lexer

import-dirs:          /usr/lib/ghc-9.4.8/site-local/language-python-0.5.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/language-python-0.5.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/language-python-0.5.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-python
hs-libraries:         HSlanguage-python-0.5.8-FU2I1gQplKQCxtgX2Peano
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    monads-tf-0.3.0.1-EWNCSzWUnVI56Lvw8xK8It pretty-1.1.3.6
    transformers-0.5.6.2 utf8-string-1.0.2-JqS4SAQdze6LQzXf6ug2xB

haddock-interfaces:
    /usr/share/doc/haskell-language-python/html/language-python.haddock

haddock-html:         /usr/share/doc/haskell-language-python/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
